@@ -913,7 +913,7 @@ get_child_environment (GtkWidget      *term,
   char **p;
   int i;
   char **retval;
-#define EXTRA_ENV_VARS 6
+#define EXTRA_ENV_VARS 7
   
   profile = screen->priv->profile;
 
@@ -932,7 +932,8 @@ get_child_environment (GtkWidget      *term,
           (strncmp (*p, "WINDOWID=", 9) == 0) ||
           (strncmp (*p, "TERM=", 5) == 0)    ||
           (strncmp (*p, "GNOME_DESKTOP_ICON=", 19) == 0) ||
-          (strncmp (*p, "COLORTERM=", 10) == 0))
+          (strncmp (*p, "COLORTERM=", 10) == 0) ||
+	  (strncmp ( *p, "DISPLAY=", 8) == 0))
         {
           /* nothing: do not copy */
         }
@@ -950,6 +951,9 @@ get_child_environment (GtkWidget      *term,
   retval[i] = g_strdup_printf ("WINDOWID=%ld",
                                GDK_WINDOW_XWINDOW (term->window));
   ++i;
+  retval[i] = g_strdup_printf ("DISPLAY=%s", 
+			       gdk_display_get_name(gtk_widget_get_display(term)));
+  ++i;
   
   retval[i] = NULL;
   
@@ -1222,8 +1226,34 @@ append_stock_menuitem (GtkWidget  *menu,
                        gpointer    data)
 {
   GtkWidget *menu_item;
+  GtkWidget *image;
+  GConfClient *client;
+  GError *error;
+  gboolean use_image;
+
   
   menu_item = gtk_image_menu_item_new_from_stock (text, NULL);
+  image = gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (menu_item));
+
+  client = gconf_client_get_default ();
+  error = NULL;
+
+  use_image = gconf_client_get_bool (client,
+                                     "/desktop/gnome/interface/menus_have_icons",
+                                      &error);
+  if (error)
+    {
+      g_printerr (_("There was an error loading config value for whether to use image in menus. (%s)\n"),error->message);
+      g_error_free (error);
+    }
+  else
+    {
+      if (use_image)
+        gtk_widget_show (image);
+      else
+        gtk_widget_hide (image);
+    }
+
   gtk_widget_show (menu_item);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu),
                          menu_item);
